Gammapy examples folder
=======================

This folder contains the following:

* Example scripts for end-users are named `example_*.py`
* Test scripts for developers are named `test_*.py`
* Work in progress coding is done in scripts named `wip_*.py`

The `test` and `wip` files are OK to have as a temp solution.
It's useful to have an example or test script for debugging while implementing something.
All code and tests should eventually go in the Gammapy package.

Note that we also have example scripts in the `docs` folder and example IPython notebooks
in the `tutorials` folder.

See info at: https://docs.gammapy.org/
